@@ -7,7 +7,7 @@ use v5.26;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Types::Standard        qw[ Str ArrayRef StrMatch Enum Bool Optional Dict ];
 use Types::Common::Numeric qw[ PositiveOrZeroInt PositiveInt ];
@@ -44,137 +44,6 @@ use overload
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 has base_filename => (
     is       => 'ro',
     isa      => Str,
@@ -520,12 +389,158 @@ sub _stringify ( $self, @ ) {
     $self->filename;
 }
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 around BUILDARGS => sub ( $orig, $class, @args ) {
 
     return $class->parse_filename( $args[0] )
       if @args == 1 && !ref $args[0];
 
-    my \%args = $class->$orig( @args );
+    my %args = $class->$orig( @args )->%*;
+
+    if ( defined( my $filename = delete $args{filename} ) ) {
+        _croak( 'specify only one of C<filename> or <base_filename>' )
+          if exists $args{base_filename};
+        %args = ( $class->parse_filename( $filename )->%*, %args );
+    }
 
     $args{$_} = [ $args{$_} ]
       for grep { $args{$_} && !is_arrayref( $args{$_} ) } qw( col_filter row_filter bin_spec );
@@ -806,6 +821,9 @@ sub to_hash;
 
 
 
+
+
+
 sub clone_with ( $self, @args ) {
     my %attr = @args == 1 ? $args[0]->%* : @args;
     return blessed( $self )->new( ( $self->TO_HASH->%*, %attr ) );
@@ -836,7 +854,7 @@ Astro::FITS::CFITSIO::FileName - parse and generate CFITSIO extended file names.
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -1016,6 +1034,7 @@ This returns the full CFITSIO filename based on all of the attributes.
 
    $fileobj = Astro::FITS::CFITSIO::FileName->new( $filename );
    $fileobj = Astro::FITS::CFITSIO::FileName->new( \%args );
+   $fileobj = Astro::FITS::CFITSIO::FileName->new( \%args );
 
 In the first example, parse a fully specified CFITSIO filename and populate
 the attributes.
@@ -1026,7 +1045,14 @@ In the second example the following arguments are available.
 
 =item base_filename I<Str>
 
-I<Required.>
+=item filename I<Str>
+
+One (and only one) of these is I<Required>.
+
+If C<base_filename> is specified, it provides the value for the C<base_filename> attribute.
+
+If C<filename> is provided, it is parsed using L</parse_filename> and provides an initial
+set of attributes; additional attributes specified in the constructor will override them.
 
 =item file_type I<Enum>
 
@@ -1144,6 +1170,9 @@ The binning expression.
 
   $new = $old->clone_with( %attr | \%attr );
 
+Create a new C<Astro::FITS::CFITSIO::FileName> object based on an
+existing one with the specified modified attributes.
+
 =head1 CLASS METHODS
 
 =head2 parse_filename
